@@ -185,42 +185,6 @@ void MAUIAndroid::shareLink(const QString &link)
         throw InterfaceConnFailedException();
 }
 
-void MAUIAndroid::shareContact(const QString &id)
-{
-    QAndroidJniObject::callStaticMethod<void>("com/kde/maui/tools/Union",
-                                              "shareContact",
-                                              "(Landroid/content/Context;"
-                                              "Ljava/lang/String;)V",
-                                              QtAndroid::androidActivity().object<jobject>(),
-                                              QAndroidJniObject::fromString(id).object<jstring>());
-}
-
-void MAUIAndroid::sendSMS(const QString &tel, const QString &subject, const QString &message)
-{
-    qDebug() << "trying to send sms text";
-    QAndroidJniEnvironment _env;
-    QAndroidJniObject activity = QAndroidJniObject::callStaticObjectMethod("org/qtproject/qt5/android/QtNative", "activity", "()Landroid/app/Activity;"); // activity is valid
-    if (_env->ExceptionCheck()) {
-        _env->ExceptionClear();
-        throw InterfaceConnFailedException();
-    }
-    if (activity.isValid()) {
-        QAndroidJniObject::callStaticMethod<void>("com/kde/maui/tools/SendIntent",
-                                                  "sendSMS",
-                                                  "(Landroid/app/Activity;Ljava/lang/String;Ljava/lang/String;Ljava/lang/String;)V",
-                                                  activity.object<jobject>(),
-                                                  QAndroidJniObject::fromString(tel).object<jstring>(),
-                                                  QAndroidJniObject::fromString(subject).object<jstring>(),
-                                                  QAndroidJniObject::fromString(message).object<jstring>());
-
-        if (_env->ExceptionCheck()) {
-            _env->ExceptionClear();
-            throw InterfaceConnFailedException();
-        }
-    } else
-        throw InterfaceConnFailedException();
-}
-
 void MAUIAndroid::openUrl(const QUrl &url)
 {
     qDebug() << "trying to open file with";
@@ -382,20 +346,6 @@ QVariantMap MAUIAndroid::createVariantMap(jobject data)
     return res;
 }
 
-QStringList MAUIAndroid::defaultPaths()
-{
-    QStringList paths;
-
-    paths.append(PATHS::HomePath);
-    paths.append(PATHS::DocumentsPath);
-    paths.append(PATHS::MusicPath);
-    paths.append(PATHS::VideosPath);
-    paths.append(PATHS::PicturesPath);
-    paths.append(PATHS::DownloadsPath);
-
-    return paths;
-}
-
 bool MAUIAndroid::checkRunTimePermissions(const QStringList &permissions)
 {
     qDebug() << "CHECKIGN PERMISSSIONS";
