@@ -4,9 +4,11 @@
 #include <QObject>
 #include <QQmlEngine>
 
+#include "mauikit_export.h"
+
 #include "abstractplatform.h"
 
-class Platform : public AbstractPlatform
+class MAUIKIT_EXPORT Platform : public AbstractPlatform
 {
     Q_OBJECT
 public:
@@ -26,7 +28,6 @@ public:
 public slots:
     void shareFiles(const QList<QUrl> &urls) override final;
     void shareText(const QString &text) override final;
-    void openUrl(const QUrl &url) override final;
     bool hasKeyboard() override final;
     bool hasMouse() override final;
 
